#!/bin/sh

# Copyright (C) 2014-2022 Daniel Baumann <daniel.baumann@open-infrastructure.net>
#
# SPDX-License-Identifier: GPL-3.0+
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

set -e

PROJECT="open-infrastructure"
SOFTWARE="compute-tools"
PROGRAM="container"

DIRECTORIES="$(for DIRECTORY in $(find /etc/${SOFTWARE}/debconf/ -type d -name ".git"); do echo $(dirname ${DIRECTORY}); done | sort -uV)"

for DIRECTORY in ${DIRECTORIES}
do
	if [ -e "${DIRECTORY}/.git" ] && [ -e /usr/bin/git ]
	then
		echo "Updating ${DIRECTORY}..."

		for FILE in "/etc/${SOFTWARE}/${PROGRAM}.conf" "/etc/${SOFTWARE}/${PROGRAM}.conf.d"/*.conf
		do
			if [ -e "${FILE}" ]
			then
				. "${FILE}"
			fi
		done

		DEBCONF_ID="${DEBCONF_ID:-HEAD}"

		cd "${DIRECTORY}"

		git clean -dfx
		git checkout -f ${DEBCONF_ID}
		git pull --rebase
		echo

		cd "${OLDPWD}"
	fi
done
